@@ -200,7 +200,7 @@ GestionnaireSP Gestionnaire::gestionnaire(const std::vector<SVM::Machine::Declar
 	gestionnaire->_initialisation = true;
 	for(const auto& e: gestionnaire->_extensions)
 	{
-		gestionnaire->_variables_extensions.insert(std::make_pair(e,std::make_shared<SVM_Interface::VariablesDefinies>(std::make_shared<SVM_Synchronisation::Acces>())));
+		gestionnaire->_variables_extensions.insert(std::make_pair(e,std::make_shared<SVM_Interface::VariablesDefinies>(std::make_shared<SVM::Machine::Interface::CacheEnsembleVariables>(),std::make_shared<SVM_Synchronisation::Acces>())));
 	}
 	gestionnaire->_piege = SVM::Machine::Debugueur::Debugueur::ajoute_piege<PiegeGestionnaireExtensions>(debugueur,gestionnaire);
 	if(static_cast<bool>(gestionnaire->_piege)) { gestionnaire->_piege->notification_changement_objet(); }
@@ -334,7 +334,7 @@ SVM_Interface::VariablesDefiniesSP Gestionnaire::variables_extension(const std::
 	std::lock_guard<std::mutex> verrou(_protection);
 	auto it = _variables_extensions.find(nom_extension);
 	if(it==_variables_extensions.end())
-		return std::make_shared<SVM_Interface::VariablesDefinies>();
+		return std::make_shared<SVM_Interface::VariablesDefinies>(std::make_shared<SVM_Interface::CacheEnsembleVariables>());
 	return it->second;
 }
 
@@ -354,7 +354,8 @@ void Gestionnaire::initialisation_generale(const SVM::Machine::MachineSP& machin
 	{
 		if(b._initialisation_generale)
 		{
-			SVM::Machine::Interface::EnvironnementSP environnement = std::make_shared<SVM::Machine::Interface::Environnement>(std::make_shared<PatronFonctionGeneriqueExtension>(b._nom,"plugin_initialisation"),machine,variables_extension(b._nom),true,true,_nettoyage);
+			auto cache_appellant = std::make_shared<SVM::Machine::Interface::CacheEnsembleVariables>();
+			SVM::Machine::Interface::EnvironnementSP environnement = std::make_shared<SVM::Machine::Interface::Environnement>(std::make_shared<PatronFonctionGeneriqueExtension>(b._nom,"plugin_initialisation"),machine,cache_appellant,variables_extension(b._nom),true,true,_nettoyage);
 			try
 			{
 				b._initialisation_generale(&environnement);
@@ -387,7 +388,8 @@ void Gestionnaire::demarrage_general(const SVM::Machine::MachineSP& machine)
 	{
 		if(b._demarrage_general)
 		{
-			SVM::Machine::Interface::EnvironnementSP environnement = std::make_shared<SVM::Machine::Interface::Environnement>(std::make_shared<PatronFonctionGeneriqueExtension>(b._nom,"plugin_startup"),machine,variables_extension(b._nom),true,true,_nettoyage);
+			auto cache_appellant = std::make_shared<SVM::Machine::Interface::CacheEnsembleVariables>();
+			SVM::Machine::Interface::EnvironnementSP environnement = std::make_shared<SVM::Machine::Interface::Environnement>(std::make_shared<PatronFonctionGeneriqueExtension>(b._nom,"plugin_startup"),machine,cache_appellant,variables_extension(b._nom),true,true,_nettoyage);
 			try
 			{
 				b._demarrage_general(&environnement);
@@ -421,7 +423,8 @@ void Gestionnaire::finalisation_generale(const SVM::Machine::MachineSP& machine)
 	{
 		if(it->_finalisation_generale)
 		{
-			SVM::Machine::Interface::EnvironnementSP environnement = std::make_shared<SVM::Machine::Interface::Environnement>(std::make_shared<PatronFonctionGeneriqueExtension>(it->_nom,"plugin_finalisation"),machine,variables_extension(it->_nom),true,true,_nettoyage);
+			auto cache_appellant = std::make_shared<SVM::Machine::Interface::CacheEnsembleVariables>();
+			SVM::Machine::Interface::EnvironnementSP environnement = std::make_shared<SVM::Machine::Interface::Environnement>(std::make_shared<PatronFonctionGeneriqueExtension>(it->_nom,"plugin_finalisation"),machine,cache_appellant,variables_extension(it->_nom),true,true,_nettoyage);
 			try
 			{
 				it->_finalisation_generale(&environnement);
